import { ActionCondition } from './actions/condition';
import { ActionBase } from './actions/base';
import { Action } from './actions/action';
export declare type ModeCondition = 'when';
export declare type ModeRequest = 'modifyMany';
export declare type ModeOperator = 'and' | 'or';
export declare type ModeCompara = 'eq';
export declare type ModeWindow = 'open';
export declare type ModeSetBusinessData = 'setApiData';
export declare type ModeSetData = 'set';
export declare type ModeSetNodeProps = 'setNodeProps';
export declare type ModeType = ModeWindow | ModeCondition | ModeRequest | ModeOperator | ModeCompara | ModeSetBusinessData | ModeSetData | ModeSetNodeProps;
export declare type ArgsType = {
    [x: string]: any;
};
export interface ActionBaseArgument {
    mode: ModeType | string;
    args?: ArgsType;
}
export declare type FullAction = ActionBase | ActionCondition | Action;
export interface ActionConditionArgument extends ActionBaseArgument {
    args?: {
        rd_if: ConditionIfData[];
        rd_else: ConditionElseData;
    };
}
export interface ConditionIfData {
    condition?: ConditionIfExpression;
    actions?: FullAction[];
}
export interface ConditionIf {
    id: string;
    actionId: string;
    condition: ConditionIfExpression;
    actions: FullAction[];
}
export interface ConditionElseData {
    actions?: FullAction[];
}
export interface ConditionElse {
    id: string;
    actionId: string;
    actions: FullAction[];
}
export interface ConditionIfExpression {
    mode: string;
    args: {
        operation?: string;
        expression?: ConditionIfExpressionSimple[];
    };
}
export interface ConditionIfExpressionSimpleBase {
    mode: string;
    args: {
        left?: any;
        right?: any;
    };
}
export declare type ConditionIfExpressionSimple = ConditionIfExpression & ConditionIfExpressionSimpleBase;
export declare type ActionRequestArgument = ActionBaseArgument & {
    args?: RequestArguments;
};
export interface BaseRequestArguments {
    id: string;
    success: any;
    fail: any;
}
export interface RequestArguments extends BaseRequestArguments {
    body: any;
}
export interface RequestArguments extends BaseRequestArguments {
    filter: any;
    body: any;
}
export interface RequestArguments extends BaseRequestArguments {
    filter: any;
    order?: any;
    pageLength?: any;
}
export interface RequestArguments extends BaseRequestArguments {
    filter: any;
}
export interface OpenWindowQuery {
    id: string;
    key: string;
    value: FullAction;
}
export interface OpenWindowArguments {
    mode: string;
    url?: string;
    page?: string;
    query?: OpenWindowQuery[];
    target?: string;
}
export declare type ActionOpenWindowArgument = ActionBaseArgument & {
    args?: OpenWindowArguments;
};
export interface BusinessSetConfigArgument {
    key?: string;
    path?: string[];
    value?: FullAction;
}
export interface BusinessSetArgument {
    id?: string;
    config?: BusinessSetConfigArgument[];
}
export declare type ActionBusinessSetArgument = ActionBaseArgument & {
    args?: BusinessSetArgument;
};
export declare type ActionCustomArgument = ActionBaseArgument & {
    args?: any;
    [x: string]: any;
};
export declare type FactoryActionArgument = ActionOpenWindowArgument & ActionConditionArgument & ActionRequestArgument & ActionBusinessSetArgument;
export interface InteractionData {
    events: interactionEventData[];
}
export interface interactionEventData {
    key: string;
    actions: FactoryActionArgument[];
}
//# sourceMappingURL=action-interface.d.ts.map