import { ActionConditionArgument, ConditionIfData } from '../action-interface';
import { RbInteraction } from '../RbInteraction';
import { ActionBase } from './base';
import { RbEvent } from './event';
export interface ConditionIfExpression {
    mode: string;
    args: {
        operation?: string;
        expression?: ConditionIfExpressionSimple[];
    };
}
export interface ConditionIfExpressionSimpleBase {
    mode: string;
    args: {
        left?: any;
        right?: any;
    };
}
export declare type ConditionIfExpressionSimple = ConditionIfExpression & ConditionIfExpressionSimpleBase;
export interface ConditionIf {
    id: string;
    actionId: string;
    condition: ConditionIfExpression;
    actions: ActionBase[];
}
export interface ConditionElse {
    id: string;
    actionId: string;
    actions: ActionBase[];
}
export declare type ActionConditionParent = RbEvent | ActionConditionIf | ActionConditionElse;
export declare class ActionCondition extends ActionBase {
    rd_if: ActionConditionIf[];
    rd_else: ActionConditionElse;
    data?: ActionConditionArgument;
    constructor(store: RbInteraction);
    constructor(store: RbInteraction, parent?: ActionConditionParent);
    constructor(store: RbInteraction, parent?: ActionConditionParent, action?: ActionConditionArgument);
    init(): void;
    initIf(rd_if: ConditionIfData[]): void;
    initElse(rd_else?: any): void;
    addActionIf(action: ActionConditionIf, sortIndex?: number): void;
    delActionIf(id: string): void;
    addActionElse(action: ActionConditionElse): void;
    expressionNew(): ConditionIfExpressionSimple;
    toTREE(): {
        key: string;
        label: string;
        children: any[];
    }[];
    toJSON(): {
        type: string;
        mode: string;
        args: {
            rd_if: {
                condition: ConditionIfExpression;
                actions: any[];
            }[];
            rd_else: {
                actions: any[];
            };
        };
    };
}
export declare class ActionConditionIf extends ActionBase<ActionCondition> {
    readonly condition: ConditionIfExpression;
    readonly actions: ActionBase[];
    constructor(store: RbInteraction, parent: ActionCondition, data?: ConditionIfData);
    expressionNew(): ConditionIfExpressionSimple;
    expressionCreate(sortIndex?: number): void;
    expressionRemove(sortIndex: number): void;
    toTREE(): {
        key: string;
        label: string;
        children: any[];
    };
    toJSON(): {
        condition: ConditionIfExpression;
        actions: any[];
    };
}
export declare class ActionConditionElse extends ActionBase {
    readonly actions: ActionBase[];
    constructor(store: RbInteraction, parent: RbEvent | ActionBase | undefined, data?: ConditionIfData);
    toTREE(): {
        key: string;
        label: string;
        children: any[];
    };
    toJSON(): {
        actions: any[];
    };
}
//# sourceMappingURL=condition.d.ts.map